==> docfbe_2_2_33_59.zip: docfbe_2_2_33_59/source/TCFbEAdjustedWeightedSumWithAverageOfColumn.cpp <==
/*
    TCFbEAdjustedWeightedSumWithAverageOfColumn.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAdjustedWeightedSumWithAverageOfColumn.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::TCFbEAdjustedWeightedSumWithAverageOfColumn(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::~TCFbEAdjustedWeightedSumWithAverageOfColumn()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// LbVNA
void __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::ClearCash(void)
{
    TCFbEWeightedSum::ClearCash();
    this->CashEnabled = false;
}

//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::GetNumerator(int NeighborIndex)
{
    if (!this->CashEnabled) {
        this->AverageOfColumn = this->DataSet->PredictionTable->GetAverageOfColumn(this->TargetColumnIndex);
    }

    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    return (Neighbor->Value - this->AverageOfColumn) *  Neighbor->Similarity;
}

//---------------------------------------------------------------------------
// \l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::GetPredictedValue(double Numerator, double Denominator)
{
    if (!this->CashEnabled) {
        this->AverageOfColumn = this->DataSet->PredictionTable->GetAverageOfColumn(this->TargetColumnIndex);
    }

    return this->AverageOfColumn + Numerator / Denominator;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_39_68.zip: docfbe_2_3_39_68/source/TCFbEAdjustedWeightedSumWithAverageOfColumn.cpp <==
/*
    TCFbEAdjustedWeightedSumWithAverageOfColumn.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAdjustedWeightedSumWithAverageOfColumn.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::TCFbEAdjustedWeightedSumWithAverageOfColumn(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::~TCFbEAdjustedWeightedSumWithAverageOfColumn()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// LbVNA
void __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::ClearCash(void)
{
    TCFbEWeightedSum::ClearCash();
    this->CashEnabled = false;
}

//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::GetNumerator(int NeighborIndex)
{
    if (!this->CashEnabled) {
        this->AverageOfColumn = this->PredictionTable->GetAverageOfColumn(this->TargetColumnIndex);
    }

    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    return (Neighbor->GetValue() - this->AverageOfColumn) *  Neighbor->GetSimilarity();
}

//---------------------------------------------------------------------------
// \l𓾂
double __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn::GetPredictedValue(double Numerator, double Denominator)
{
    if (!this->CashEnabled) {
        this->AverageOfColumn = this->PredictionTable->GetAverageOfColumn(this->TargetColumnIndex);
    }

    return this->AverageOfColumn + Numerator / Denominator;
}

//---------------------------------------------------------------------------
